==> material-react-table-2.11.1.tgz: package/locales/pl/index.esm.js <==
const MRT_Localization_PL = {
    actions: 'Akcje',
    and: 'i',
    cancel: 'Anuluj',
    changeFilterMode: 'Zmień tryb filtrowania',
    changeSearchMode: 'Zmień tryb wyszukiwania',
    clearFilter: 'Wyczyść filtr',
    clearSearch: 'Wyczyść wyszukiwanie',
    clearSelection: 'Wyczyść zaznaczenie',
    clearSort: 'Wyczyść sortowanie',
    clickToCopy: 'Kliknij, aby skopiować',
    copy: 'Kopiuj',
    collapse: 'Zwiń',
    collapseAll: 'Zwiń wszystko',
    columnActions: 'Akcje dla kolumny',
    copiedToClipboard: 'Skopiowano do schowka',
    dropToGroupBy: 'Upuść aby zgrupować wg {column}',
    edit: 'Edytuj',
    expand: 'Rozwiń',
    expandAll: 'Rozwiń wszystko',
    filterArrIncludes: 'Zawiera',
    filterArrIncludesAll: 'Zawiera wszystko',
    filterArrIncludesSome: 'Zawiera niektóre',
    filterBetween: 'Pomiędzy (przedział otwarty)',
    filterBetweenInclusive: 'Pomiędzy (przedział domknięty)',
    filterByColumn: 'Filtruj wg {column}',
    filterContains: 'Zawiera',
    filterEmpty: 'Puste',
    filterEndsWith: 'Kończy się na',
    filterEquals: 'Równa się',
    filterEqualsString: 'Równa się',
    filterFuzzy: 'Rozmyte dopasowanie',
    filterGreaterThan: 'Większe niż',
    filterGreaterThanOrEqualTo: 'Większe lub równe',
    filterInNumberRange: 'Pomiędzy',
    filterIncludesString: 'Zawiera',
    filterIncludesStringSensitive: 'Zawiera (istotna wielkość znaków)',
    filterLessThan: 'Mniejsze niż',
    filterLessThanOrEqualTo: 'Mniejsze lub równe',
    filterMode: 'Tryb filtrowania: {filterType}',
    filterNotEmpty: 'Nie jest puste',
    filterNotEquals: 'Nie równa się',
    filterStartsWith: 'Zaczyna się od',
    filterWeakEquals: 'Równa się',
    filteringByColumn: 'Filtrowanie wg {column} - {filterType} {filterValue}',
    goToFirstPage: 'Pierwsza strona',
    goToLastPage: 'Ostatnia strona',
    goToNextPage: 'Następna strona',
    goToPreviousPage: 'Poprzednia strony',
    grab: 'Grab',
    groupByColumn: 'Grupuj wg {column}',
    groupedBy: 'Grupowane wg ',
    hideAll: 'Ukryj wszystko',
    hideColumn: 'Ukryj kolumnę {column}',
    max: 'Maks.',
    min: 'Min.',
    move: 'Przenieś',
    noRecordsToDisplay: 'Brak rekordów do wyświetlenia',
    noResultsFound: 'Brak wyników',
    of: 'z',
    or: 'lub',
    pin: 'Przypnij',
    pinToLeft: 'Przypnij po lewej',
    pinToRight: 'Przypnij po prawej',
    resetColumnSize: 'Resetuj wielkość kolumn',
    resetOrder: 'Resetuj kolejność',
    rowActions: 'Akcje dla rekordu',
    rowNumber: '#',
    rowNumbers: 'Liczba rekordów',
    rowsPerPage: 'Rekordów na stronę',
    save: 'Zapisz',
    search: 'Szukaj',
    selectedCountOfRowCountRowsSelected: 'Wybrano {selectedCount} z {rowCount} rekordów',
    select: 'Wybierz',
    showAll: 'Pokaż wszystko',
    showAllColumns: 'Pokaż wszystkie kolumny',
    showHideColumns: 'Pokaż/ukryj kolumny',
    showHideFilters: 'Pokaż/ukryj filtry',
    showHideSearch: 'Pokaż/ukryj wyszukiwanie',
    sortByColumnAsc: 'Sortuj wg {column} rosnąco',
    sortByColumnDesc: 'Sortuj wg {column} malejąco',
    sortedByColumnAsc: 'Sortuj wg {column} rosnąco',
    sortedByColumnDesc: 'Sortuj wg {column} malejąco',
    thenBy: ', następnie wg ',
    toggleDensity: 'Przełącz gęstość rekordów',
    toggleFullScreen: 'Tryb pełnoekranowy',
    toggleSelectAll: 'Zaznacz wszystkie',
    toggleSelectRow: 'Zaznacz rekord',
    toggleVisibility: 'Widoczność',
    ungroupByColumn: 'Rozgrupuj {column}',
    unpin: 'Odepnij',
    unpinAll: 'Odepnij wszystkie',
};

export { MRT_Localization_PL };

==> material-react-table-3.0.0-rc.0.tgz: package/locales/pl/index.esm.js <==
const MRT_Localization_PL = {
    actions: 'Akcje',
    and: 'i',
    cancel: 'Anuluj',
    changeFilterMode: 'Zmień tryb filtrowania',
    changeSearchMode: 'Zmień tryb wyszukiwania',
    clearFilter: 'Wyczyść filtr',
    clearSearch: 'Wyczyść wyszukiwanie',
    clearSelection: 'Wyczyść zaznaczenie',
    clearSort: 'Wyczyść sortowanie',
    clickToCopy: 'Kliknij, aby skopiować',
    copy: 'Kopiuj',
    collapse: 'Zwiń',
    collapseAll: 'Zwiń wszystko',
    columnActions: 'Akcje dla kolumny',
    copiedToClipboard: 'Skopiowano do schowka',
    dropToGroupBy: 'Upuść aby zgrupować wg {column}',
    edit: 'Edytuj',
    expand: 'Rozwiń',
    expandAll: 'Rozwiń wszystko',
    filterArrIncludes: 'Zawiera',
    filterArrIncludesAll: 'Zawiera wszystko',
    filterArrIncludesSome: 'Zawiera niektóre',
    filterBetween: 'Pomiędzy (przedział otwarty)',
    filterBetweenInclusive: 'Pomiędzy (przedział domknięty)',
    filterByColumn: 'Filtruj wg {column}',
    filterContains: 'Zawiera',
    filterEmpty: 'Puste',
    filterEndsWith: 'Kończy się na',
    filterEquals: 'Równa się',
    filterEqualsString: 'Równa się',
    filterFuzzy: 'Rozmyte dopasowanie',
    filterGreaterThan: 'Większe niż',
    filterGreaterThanOrEqualTo: 'Większe lub równe',
    filterInNumberRange: 'Pomiędzy',
    filterIncludesString: 'Zawiera',
    filterIncludesStringSensitive: 'Zawiera (istotna wielkość znaków)',
    filterLessThan: 'Mniejsze niż',
    filterLessThanOrEqualTo: 'Mniejsze lub równe',
    filterMode: 'Tryb filtrowania: {filterType}',
    filterNotEmpty: 'Nie jest puste',
    filterNotEquals: 'Nie równa się',
    filterStartsWith: 'Zaczyna się od',
    filterWeakEquals: 'Równa się',
    filteringByColumn: 'Filtrowanie wg {column} - {filterType} {filterValue}',
    goToFirstPage: 'Pierwsza strona',
    goToLastPage: 'Ostatnia strona',
    goToNextPage: 'Następna strona',
    goToPreviousPage: 'Poprzednia strony',
    grab: 'Grab',
    groupByColumn: 'Grupuj wg {column}',
    groupedBy: 'Grupowane wg ',
    hideAll: 'Ukryj wszystko',
    hideColumn: 'Ukryj kolumnę {column}',
    max: 'Maks.',
    min: 'Min.',
    move: 'Przenieś',
    noRecordsToDisplay: 'Brak wyników do wyświetlenia',
    noResultsFound: 'Brak wyników',
    of: 'z',
    or: 'lub',
    pin: 'Przypnij',
    pinToLeft: 'Przypnij po lewej',
    pinToRight: 'Przypnij po prawej',
    resetColumnSize: 'Resetuj wielkość kolumn',
    resetOrder: 'Resetuj kolejność',
    rowActions: 'Akcje dla rekordu',
    rowNumber: '#',
    rowNumbers: 'Liczba wyników',
    rowsPerPage: 'Wyników na stronę',
    save: 'Zapisz',
    search: 'Szukaj',
    selectedCountOfRowCountRowsSelected: 'Wybrano {selectedCount} z {rowCount} wyników',
    select: 'Wybierz',
    showAll: 'Pokaż wszystko',
    showAllColumns: 'Pokaż wszystkie kolumny',
    showHideColumns: 'Pokaż/ukryj kolumny',
    showHideFilters: 'Pokaż/ukryj filtry',
    showHideSearch: 'Pokaż/ukryj wyszukiwanie',
    sortByColumnAsc: 'Sortuj wg {column} rosnąco',
    sortByColumnDesc: 'Sortuj wg {column} malejąco',
    sortedByColumnAsc: 'Sortuj wg {column} rosnąco',
    sortedByColumnDesc: 'Sortuj wg {column} malejąco',
    thenBy: ', następnie wg ',
    toggleDensity: 'Przełącz gęstość wyników',
    toggleFullScreen: 'Tryb pełnoekranowy',
    toggleSelectAll: 'Zaznacz wszystkie',
    toggleSelectRow: 'Zaznacz rekord',
    toggleVisibility: 'Widoczność',
    ungroupByColumn: 'Rozgrupuj {column}',
    unpin: 'Odepnij',
    unpinAll: 'Odepnij wszystkie',
};

export { MRT_Localization_PL };
